@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -11,15 +11,14 @@
 #ifndef CKalmanFilterCapable_H
 #error Include this file only from 'CKalmanFilterCapable.h'
 #endif
-
+//
+#include <mrpt/bayes/CKalmanFilterCapable.h>
 #include <mrpt/containers/stl_containers_utils.h>
 #include <mrpt/math/ops_matrices.h>	 // extractSubmatrixSymmetrical()
 
 #include <Eigen/Dense>
 
-namespace mrpt
-{
-namespace bayes
+namespace mrpt::bayes
 {
 // The main entry point in the Kalman Filter class:
 template <
@@ -1148,5 +1147,4 @@ inline bool isMapEmpty(
 	return true;
 }
 }  // namespace detail
-}  // namespace bayes
-}  // namespace mrpt
+}  // namespace mrpt::bayes
