@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -81,11 +81,15 @@ constexpr inline long double RAD2DEG(const long double x)
 #define DEG2RAD DEG2RAD
 #define RAD2DEG RAD2DEG
 
+namespace literals
+{
 /** degrees to radian literal operator (e.g. `x=90.0_deg;`) */
 constexpr inline double operator"" _deg(long double v)
 {
 	return static_cast<double>(mrpt::DEG2RAD(v));
 }
+}  // namespace literals
+using namespace mrpt::literals;	 // for backwards compatib.
 
 /** Returns the sign of X as "1" or "-1" */
 template <typename T>
