@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -27,8 +27,8 @@ TEST(WorkerThreadsPool, runTasks)
 		auto fut3 = pool.enqueue(f, 3);
 
 		const auto n = pool.pendingTasks();
-		EXPECT_GE(n, 0);
-		EXPECT_LE(n, 3);
+		EXPECT_GE(n, 0U);
+		EXPECT_LE(n, 3U);
 
 		fut1.wait();
 		fut2.wait();
