@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -10,9 +10,10 @@
 #include "graphs-precomp.h"	 // Precompiled headers
 //
 #include <mrpt/core/initializer.h>
+#include <mrpt/graphs/registerAllClasses.h>
+// Deps:
+#include <mrpt/opengl/registerAllClasses.h>
 
-// using namespace mrpt::graphs;
-//
 MRPT_INITIALIZER(registerAllClasses_mrpt_graphs)
 {
 #if !defined(DISABLE_MRPT_AUTO_CLASS_REGISTRATION)
@@ -20,3 +21,10 @@ MRPT_INITIALIZER(registerAllClasses_mrpt_graphs)
 
 #endif
 }
+
+void mrpt::graphs::registerAllClasses_mrpt_graphs()
+{
+	::registerAllClasses_mrpt_graphs();
+	// deps:
+	mrpt::opengl::registerAllClasses_mrpt_opengl();
+}
