@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -73,7 +73,7 @@ class CPlanarLaserScan : public CRenderizableShaderPoints,
 	virtual shader_list_t requiredShaders() const override
 	{
 		return {
-			DefaultShaderID::WIREFRAME, DefaultShaderID::TRIANGLES,
+			DefaultShaderID::WIREFRAME, DefaultShaderID::TRIANGLES_NO_LIGHT,
 			DefaultShaderID::POINTS};
 	}
 	void onUpdateBuffers_Wireframe() override;
@@ -139,7 +139,7 @@ class CPlanarLaserScan : public CRenderizableShaderPoints,
 		m_scan = scan;
 	}
 
-	auto getBoundingBox() const -> mrpt::math::TBoundingBox override;
+	auto internalBoundingBoxLocal() const -> mrpt::math::TBoundingBoxf override;
 
    protected:
 	mrpt::obs::CObservation2DRangeScan m_scan;
