@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -41,6 +41,12 @@ double TPlane::distance(const TPoint3D& point) const
 {
 	return std::abs(evaluatePoint(point)) / sqrt(squareNorm<3, double>(coefs));
 }
+
+double TPlane::signedDistance(const TPoint3D& point) const
+{
+	return evaluatePoint(point) / sqrt(squareNorm<3, double>(coefs));
+}
+
 double TPlane::distance(const TLine3D& line) const
 {
 	if (std::abs(getAngle(*this, line)) >= getEpsilon())
