@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -57,7 +57,7 @@ class CAssimpModel : public CRenderizableShaderTriangles,
 	{
 		// May use up to two shaders (triangles and lines):
 		return {
-			DefaultShaderID::WIREFRAME, DefaultShaderID::TRIANGLES,
+			DefaultShaderID::WIREFRAME, DefaultShaderID::TRIANGLES_LIGHT,
 			DefaultShaderID::POINTS};
 	}
 	void onUpdateBuffers_Wireframe() override;
@@ -70,9 +70,10 @@ class CAssimpModel : public CRenderizableShaderTriangles,
 		CRenderizableShaderWireFrame::freeOpenGLResources();
 		CRenderizableShaderPoints::freeOpenGLResources();
 	}
-	void enqueForRenderRecursive(
-		const mrpt::opengl::TRenderMatrices& state,
-		RenderQueue& rq) const override;
+	void enqueueForRenderRecursive(
+		const mrpt::opengl::TRenderMatrices& state, RenderQueue& rq,
+		bool wholeInView) const override;
+	bool isCompositeObject() const override { return true; }
 	/** @} */
 
 	CAssimpModel();
@@ -117,7 +118,7 @@ class CAssimpModel : public CRenderizableShaderTriangles,
 	/* Simulation of ray-trace. */
 	bool traceRay(const mrpt::poses::CPose3D& o, double& dist) const override;
 
-	mrpt::math::TBoundingBox getBoundingBox() const override;
+	mrpt::math::TBoundingBoxf internalBoundingBoxLocal() const override;
 
 	struct TInfoPerTexture
 	{
@@ -151,6 +152,8 @@ class CAssimpModel : public CRenderizableShaderTriangles,
 		mrpt::opengl::internal::RenderElements& re);
 	void process_textures(const aiScene* scene);
 
+	void after_load_model();
+
 };	// namespace mrpt::opengl
 
 }  // namespace mrpt::opengl
